@@ -135,12 +135,16 @@ segm_meanshift <- function(image,
     if (mode == "vector") {
         segm.out.path            <- tempfile(fileext = ".shp")
         cmd$mode.vector.out      <- segm.out.path
-        cmd$mode.vector.inmask   <- mask
         cmd$mode.vector.neighbor <- tolower(vector_neighbor)
         cmd$mode.vector.stitch   <- tolower(vector_stitch)
         cmd$mode.vector.tilesize <- vector_tilesize
         cmd$mode.vector.minsize <- vector_minsize
         cmd$mode.vector.simplify <- vector_simplify
+        if (inherits(mask, "SpatRaster")) {
+            mask.path <- tempfile(fileext = ".tiff")
+            terra::writeRaster(mask, mask.path)
+            cmd$mode.vector.inmask   <- mask.path
+        }
     } else {
         segm.out.path       <- tempfile(fileext = ".tiff")
         cmd$mode.raster.out <- segm.out.path
@@ -412,12 +416,16 @@ segm_watershed <- function(image,
     if (mode == "vector") {
         segm.out.path            <- tempfile(fileext = ".shp")
         cmd$mode.vector.out      <- segm.out.path
-        cmd$mode.vector.inmask   <- mask
         cmd$mode.vector.neighbor <- tolower(vector_neighbor)
         cmd$mode.vector.stitch   <- tolower(vector_stitch)
         cmd$mode.vector.minsize  <- vector_minsize
         cmd$mode.vector.tilesize  <- vector_tilesize
         cmd$mode.vector.simplify <- vector_simplify
+        if (inherits(mask, "SpatRaster")) {
+            mask.path <- tempfile(fileext = ".tiff")
+            terra::writeRaster(mask, mask.path)
+            cmd$mode.vector.inmask   <- mask.path
+        }
     } else {
         segm.out.path       <- tempfile(fileext = ".tiff")
         cmd$mode.raster.out <- segm.out.path
@@ -561,12 +569,16 @@ segm_mprofiles <- function(image,
     if (mode == "vector") {
         segm.out.path            <- tempfile(fileext = ".shp")
         cmd$mode.vector.out      <- segm.out.path
-        cmd$mode.vector.inmask   <- mask
         cmd$mode.vector.neighbor <- tolower(vector_neighbor)
         cmd$mode.vector.stitch   <- tolower(vector_stitch)
         cmd$mode.vector.minsize  <- vector_minsize
         cmd$mode.vector.tilesize  <- vector_tilesize
         cmd$mode.vector.simplify <- vector_simplify
+        if (inherits(mask, "SpatRaster")) {
+            mask.path <- tempfile(fileext = ".tiff")
+            terra::writeRaster(mask, mask.path)
+            cmd$mode.vector.inmask   <- mask.path
+        }
     } else {
         segm.out.path       <- tempfile(fileext = ".tiff")
         cmd$mode.raster.out <- segm.out.path
